################################################################################
## Author: V. Agudetse
## Description: Preliminary sample script for PATC 2023,
################################################################################

# Load modules
source("modules/Loading/Loading.R")
source("modules/Units/Units.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")

# Read recipe
recipe_file <- "use_cases/PATC_2023/recipe_PATC_2023.yml"
recipe <- prepare_outputs(recipe_file)

# Load datasets
data <- Loading(recipe)
# Change units
data <- Units(recipe, data)
# Calibrate datasets
data <- Calibration(recipe, data)
# Compute anomalies
data <- Anomalies(recipe, data)
# Compute skill metrics 
skill_metrics <- Skill(recipe, data)
# Compute percentiles and probability bins
probabilities <- Probabilities(recipe, data)
# Plot data
Visualization(recipe, data, skill_metrics, probabilities, significance = T)

